@@ -7,6 +7,7 @@ import (
 	"reflect"
 	"testing"
 
+	"github.com/stretchr/testify/assert"
 	"sigs.k8s.io/kustomize/api/provider"
 	"sigs.k8s.io/kustomize/api/types"
 	"sigs.k8s.io/kustomize/kustomize/v5/commands/internal/kustfile"
@@ -53,6 +54,14 @@ func TestCreateWithResources(t *testing.T) {
 	}
 }
 
+func TestCreateWithResourcesWithFileNotFound(t *testing.T) {
+	fSys := filesys.MakeEmptyDirInMemory()
+	assert.NoError(t, fSys.WriteFile("foo.yaml", []byte("")))
+	opts := createFlags{resources: "foo.yaml,bar.yaml"}
+	err := runCreate(opts, fSys, factory)
+	assert.EqualError(t, err, "bar.yaml has no match: must build at directory: not a valid directory: 'bar.yaml' doesn't exist")
+}
+
 func TestCreateWithNamespace(t *testing.T) {
 	fSys := filesys.MakeFsInMemory()
 	want := "foo"
